from google.cloud import vision
from google.cloud.vision import types


class Image:
    def __init__(self, image_uri):
        self.google = vision.ImageAnnotatorClient()
        self.image_uri = image_uri

    @property
    def image(self):
        image = types.Image()
        image.source.image_uri = self.image_uri
        return image

    def get_text(self):
        print(
            "Requesting TEXT_DETECTION from Google Cloud API. This will cost us 0.0015 USD."
        )
        response = self.google.text_detection(image=self.image)
        self.text_found = response.text_annotations



"""
PogoOCR
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

A Python tool for running OCR on Pokemon Screenshots using Google Cloud Vision

:copyright: (c) 2018 TrainerDex
:licence: Undecided, ask permission before using.

"""

__title__ = "PogoOCR"
__author__ = "JayTurnr"
__licence__ = "GNU GENERAL PUBLIC LICENSE 3.0"
__copyright__ = "2018 TrainerDex"
__version__ = "0.0.2"

from .cloudvision import *
from .types import *



from .cloudvision import Image
import re


class ProfileTop(Image):
    @property
    def username(self):
        return re.search(
            r"([A-Za-z0-9]+)\n(?:\&|et|con|e) ?(.+)", self.text_found[0].description
        ).group(1)

    @property
    def buddy_name(self):
        return re.search(
            r"([A-Za-z0-9]+)\n(?:\&|et|con|e) ?(.+)", self.text_found[0].description
        ).group(2)


class ProfileBottom(Image):
    @property
    def start_date_text(self):
        re_pattern = r"(?:(?:Start\s?Date)|(?:始めた日)|(?:Date\s?de\s?début)|(?:Date\s?de\s?debut)|(?:Fecha\s?de\s?inicio)|(?:Startdatum)|(?:Data\s?di\si?nizio)|(?:시작한\s?날)|(?:開始日)|(?:Data\s?de\s?início))(?::|：)?\s?(\d{1,4}(\/|.|\\)\d{1,2}(\/|.|\\)\d{1,4})"
        return re.search(
            re_pattern, self.text_found[0].description, re.IGNORECASE
        ).group(1)

    @property
    def total_xp(self):
        re_pattern = r"(?:(?:Total\s?XP)|(?:TOTAL\s?XP)|(?:Total\s?de\s?PX)|(?:Gesamt-EP)|(?:Totale\s?PE)|(?:總XP)|(?:Total\s?de\s?PE))\s?(?::|：)?\s?([\d,.\s]+)"
        return re.search(
            re_pattern, self.text_found[0].description, re.IGNORECASE
        ).group(1)



import setuptools
import re

with open("README.rst", "r") as f:
    readme = f.read()

with open("PogoOCR/__init__.py", "r") as f:
    version = re.search(r'__version__\s*=\s*[\'"]([^\'"]*)[\'"]', f.read()).group(1)

with open("requirements.txt", "r") as f:
    requirements = f.read().splitlines()

setuptools.setup(
    name="PogoOCR",
    version=version,
    author="Jay Turner",
    author_email="jay@trainerdex.co.uk",
    description="A Python tool for running OCR on Pokemon Screenshots",
    long_description=readme,
    long_description_content_type="text/x-rst",
    url="https://github.com/TrainerDex/PogoOCR",
    packages=setuptools.find_packages(),
    data_files=[("PogoOCR", ["PogoOCR/testing_images.yaml"])],
    install_requires=requirements,
    python_requires=">=3.6",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
